==> openorienteering-mapper_0.6.3.orig.tar.gz: mapper-0.6.3/translations/OpenOrienteering_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AutosaveDialog</name>
    <message numerus="yes">
        <location filename="../src/gui/autosave_dialog.cpp" line="45"/>
        <location filename="../src/gui/autosave_dialog.cpp" line="51"/>
        <source>%n bytes</source>
        <translation>
            <numerusform>%n byte</numerusform>
            <numerusform>%n bytes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message numerus="yes">
        <location filename="../src/file_import_export.cpp" line="93"/>
        <source>Dropped %n irregular object(s).</source>
        <translation>
            <numerusform>Dropped one irregular object.</numerusform>
            <numerusform>Dropped %n irregular objects.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OCAD8FileImport</name>
    <message numerus="yes">
        <location filename="../src/file_format_ocad8.cpp" line="145"/>
        <source>%n color separation(s) were skipped, reason: Import disabled.</source>
        <translation>
            <numerusform>One color separation was skipped, reason: Import disabled.</numerusform>
            <numerusform>%n color separations were skipped, reason: Import disabled.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TemplateTrack</name>
    <message numerus="yes">
        <location filename="../src/template_track.cpp" line="479"/>
        <source>%n path object(s) could not be imported (reason: missing coordinates).</source>
        <translation>
            <numerusform>One path object could not be imported (reason: missing coordinates).</numerusform>
            <numerusform>%n path objects could not be imported (reason: missing coordinates).</numerusform>
        </translation>
    </message>
</context>
</TS>

==> openorienteering-mapper_0.6.5.orig.tar.gz: mapper-0.6.5/translations/OpenOrienteering_en.ts <==
<?xml version='1.0' encoding='utf-8'?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>AutosaveDialog</name>
    <message numerus="yes">
        <location filename="../src/gui/autosave_dialog.cpp" line="45"></location>
        <location filename="../src/gui/autosave_dialog.cpp" line="51"></location>
        <source>%n bytes</source>
        <translation>
            <numerusform>%n byte</numerusform>
            <numerusform>%n bytes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message numerus="yes">
        <location filename="../src/file_import_export.cpp" line="93"></location>
        <source>Dropped %n irregular object(s).</source>
        <translation>
            <numerusform>Dropped one irregular object.</numerusform>
            <numerusform>Dropped %n irregular objects.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OCAD8FileImport</name>
    <message numerus="yes">
        <location filename="../src/file_format_ocad8.cpp" line="145"></location>
        <source>%n color separation(s) were skipped, reason: Import disabled.</source>
        <translation>
            <numerusform>One color separation was skipped, reason: Import disabled.</numerusform>
            <numerusform>%n color separations were skipped, reason: Import disabled.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TemplateTrack</name>
    <message numerus="yes">
        <location filename="../src/template_track.cpp" line="479"></location>
        <source>%n path object(s) could not be imported (reason: missing coordinates).</source>
        <translation>
            <numerusform>One path object could not be imported (reason: missing coordinates).</numerusform>
            <numerusform>%n path objects could not be imported (reason: missing coordinates).</numerusform>
        </translation>
    </message>
</context>
</TS>
